Page 55 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 55

Home

    doctrine is not only to repudiate Christianity, but to
    strike at the very root of all morality.'*

    In the course of planning for the happiness of the
    human race, and to transform France into a Socialist

    State with absolute equality and universal contentment,
    Robespierre and his followers decided that the

    Robespierre and his followers decided that the
    population must be reduced by more than half.

    This began what was known as the Reign of Terror
    whereby war was waged against everything that makes
    up a civilized society. This war, of the government of
    France against its own people, was as terrible and
    destructive as any that could have been carried out by an
    invading army. It was waged with special fury on the
    manufacturing towns.

    The magnificent city of Lyon was literally demolished
    as orators incited the working-class to violence against
    the owners of industry. Nor did the war stop with
    industry, but extended to education, science, art, and

    and

    decided

    that

    the

    nothing. :
    Men of education

    were

    persecution. Even the appearance of culture became
    dangerous and, in order to survive, it became necessary
    to dress unkempt and careless and to assume a rough

    manner. Just to show politeness and good manners
    placed one in danger of the guillotine.

    50

    The Secret Side of History

    literature. Throughout France, thousands of books and

    valuable pictures were destroyed or sold for next to

    subject to

    arrest and